@@ -92,6 +92,12 @@ METADATA_SERVICE_HEADERS = json.loads(from_conf('METAFLOW_SERVICE_HEADERS', '{}'
 if METADATA_SERVICE_AUTH_KEY is not None:
     METADATA_SERVICE_HEADERS['x-api-key'] = METADATA_SERVICE_AUTH_KEY
 
+###
+# Aero Token Information
+AERO_ID_TOKEN = from_conf('AERO_ID_TOKEN')
+AERO_IDENTITY_POOL = from_conf('AERO_IDENTITY_POOL')
+AERO_PROVIDER = from_conf('AERO_PROVIDER')
+
 ###
 # AWS Batch configuration
 ###
