@@ -5,6 +5,7 @@ import sys
 from .util import get_username, to_unicode
 from . import metaflow_version
 from metaflow.exception import MetaflowException
+from metaflow.mflog import BASH_MFLOG, BASH_SAVE_LOGS
 from . import R
 
 version_cache = None
@@ -78,7 +79,7 @@ class MetaflowEnvironment(object):
         return "Local environment"
 
     def get_package_commands(self, code_package_url):
-        cmds = ["set -e",
+        cmds = [BASH_MFLOG,
                 "%s -m pip install awscli click requests boto3 -qqq" 
                     % self._python(),
                 "mkdir metaflow",
@@ -90,10 +91,10 @@ class MetaflowEnvironment(object):
                     "sleep 10; i=$((i+1)); "
                 "done" % (self._python(), code_package_url),
                 "if [ $i -gt 5 ]; then "
-                    "echo \'Failed to download code package from %s "
-                    "after 6 tries. Exiting...\' && exit 1; "
-                "fi" % code_package_url,
-                "tar xf job.tar"
+                    "exit 1; "
+                "fi",
+                "tar xf job.tar",
+                "mflog \'Task is starting.\'",
                 ]
         return cmds
 
