@@ -29,13 +29,15 @@ from metaflow.mflog import export_mflog_env_vars,\
                            update_delay,\
                            BASH_SAVE_LOGS
 
+TRACKING_URL = "https://dev.aeroplatform.co.uk/tracking?vcpus={vcpus}&memory={memory}"
+
 # Redirect structured logs to /logs/
 LOGS_DIR = '/logs'
 STDOUT_FILE = 'mflog_stdout'
 STDERR_FILE = 'mflog_stderr'
 STDOUT_PATH = os.path.join(LOGS_DIR, STDOUT_FILE)
 STDERR_PATH = os.path.join(LOGS_DIR, STDERR_FILE)
-TRACKING_URL = "https://api.aeroplatform.co.uk/tracking?vcpus={vcpus}&memory={memory}"
+TRACKING_URL = "https://dev.aeroplatform.co.uk/tracking?vcpus={vcpus}&memory={memory}"
 
 class BatchException(MetaflowException):
     headline = 'AWS Batch error'
@@ -306,9 +308,6 @@ class Batch(object):
 
                 else:
                     parsed_body = resp.json()
-                    print(parsed_body)
-                    current_vcpus = parsed_body['vcpus']
-                    cpu_limit = parsed_body['vcpus_limit']
 
                     # If limit smaller than requested
                     if parsed_body['vcpus_limit'] < parsed_body['requested_vcpus']:
@@ -322,11 +321,13 @@ class Batch(object):
 
                     time.sleep(60)
                 
-                    if requested_cpu + current_vcpus > cpu_limit:
+                    if pre_job.cpu + current_vcpus > cpu_limit:
                         echo(f"New job of {pre_job.cpu} would push CPU usage to {pre_job.cpu + current_vcpus}, which is higher than the limit of {cpu_limit}")
                     else:
                         echo(f"Requesting {pre_job.cpu} vcpus, current usage now {pre_job.cpu + current_vcpus}")
                         job_blocked = False
+            
+
 
         def wait_for_launch(job):
             status = job.status
